@@ -8,13 +8,16 @@ import (
 	"io"
 	mathrand "math/rand"
 	"reflect"
+	"strings"
 	"testing"
 	"time"
 
 	"github.com/bitnami-labs/sealed-secrets/pkg/crypto"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/kubernetes/fake"
+	ktesting "k8s.io/client-go/testing"
 	certUtil "k8s.io/client-go/util/cert"
 	"k8s.io/client-go/util/keyutil"
 )
@@ -86,7 +89,12 @@ func TestWriteKey(t *testing.T) {
 
 	client := fake.NewSimpleClientset()
 
-	_, err = writeKey(ctx, client, key, []*x509.Certificate{cert}, "myns", "label", "mykey")
+	namespace := "myns"
+	defaultLabel := "default-label"
+	myKey := "mykey"
+	additionalAnnotations := "testAnnotation1=additional.annotation,test.annotation.2=test/2"
+	additionalLabels := "testLabel1=additional.label,test.label.2=test/2"
+	_, err = writeKey(ctx, client, key, []*x509.Certificate{cert}, namespace, defaultLabel, myKey, additionalAnnotations, additionalLabels)
 	if err != nil {
 		t.Errorf("writeKey() failed with: %v", err)
 	}
@@ -95,7 +103,37 @@ func TestWriteKey(t *testing.T) {
 
 	if a := findAction(client, "create", "secrets"); a == nil {
 		t.Errorf("writeKey didn't create a secret")
-	} else if a.GetNamespace() != "myns" {
+	} else if a.GetNamespace() != namespace {
 		t.Errorf("writeKey() created key in wrong namespace!")
 	}
+	a := findAction(client, "create", "secrets").(ktesting.CreateActionImpl)
+	secret, _ := runtime.DefaultUnstructuredConverter.ToUnstructured(a.Object)
+	generateName := secret["metadata"].(map[string]interface{})["generateName"].(string)
+
+	if generateName != myKey {
+		t.Errorf("writeKey didn't set the correct name")
+	}
+
+	labels := secret["metadata"].(map[string]interface{})["labels"]
+	annotations := secret["metadata"].(map[string]interface{})["annotations"]
+
+	if labels.(map[string]interface{})[defaultLabel] != "active" {
+		t.Errorf("writeKey didn't set default label")
+	}
+
+	for _, label := range strings.Split(additionalLabels, ",") {
+		labelKey := strings.Split(label, "=")[0]
+		labelValue := strings.Split(label, "=")[1]
+		if labels.(map[string]interface{})[labelKey] != labelValue {
+			t.Errorf("writeKey didn't set label " + labelKey + " to value '" + labelValue + "'")
+		}
+	}
+
+	for _, annotation := range strings.Split(additionalAnnotations, ",") {
+		annotationKey := strings.Split(annotation, "=")[0]
+		annotationValue := strings.Split(annotation, "=")[1]
+		if annotations.(map[string]interface{})[annotationKey] != annotationValue {
+			t.Errorf("writeKey didn't set annotation '" + annotationKey + "' to value '" + annotationValue + "'")
+		}
+	}
 }
